import configparser
import os

import allure
import pytest
from selenium import webdriver
from selenium.webdriver.chrome.options import Options



def get_config_param(path, part, param_name):
    config = configparser.ConfigParser()
    config.read(path)
    return config.get(part, param_name)

@pytest.mark.tryfirst
def pytest_runtest_makereport(item, __multicall__):
    rep = __multicall__.execute()
    setattr(item, "rep_" + rep.when, rep)
    return rep

def root_dir():
    ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
    return ROOT_DIR


def browser_chrome(ROOT_DIR, impl_wait=15, window_width=1920, window_height=1080):
    chrome_options = Options()
    # chrome_options.add_argument('--headless')
    chrome_options.add_argument('--no-sandbox')
    chrome_options.add_argument('--disable-dev-shm-usage')
    # chrome_options.add_argument("--disable-extensions")
    chrome_options.add_experimental_option("prefs", {
        "download.default_directory": f"{ROOT_DIR}/downloads",
        "download.prompt_for_download": False,
        "download.directory_upgrade": True,
        "safebrowsing.enabled": True
    })
    driver = webdriver.Chrome(chrome_options=chrome_options)
    driver.implicitly_wait(impl_wait)
    driver.set_window_size(window_width, window_height)
    driver.maximize_window()
    return driver

def fin_fails_with_picture(driver, request):
    attach = driver.get_screenshot_as_png()
    if request.node.rep_setup.failed:
        allure.attach(attach, attachment_type=allure.attachment_type.PNG)
    elif request.node.rep_setup.passed:
        if request.node.rep_call.failed:
            allure.attach(attach, attachment_type=allure.attachment_type.PNG)
    driver.quit()


def base_url_check(request):
    if request.config.getoption("--url"):
        return request.config.getoption("--url")
    else:
        return base_url
