import allure
from selenium.common import exceptions
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.support.wait import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.common.by import By
import csv

class BasePage:

    def __init__(self, driver):
        self.driver = driver

    @allure.step("Найти элемент по локатору")
    def find_element(self, locator, time=20):
        return WebDriverWait(self.driver, time).until(EC.presence_of_element_located(locator), message=f"Can't found element {locator}")

    @allure.step("Найти элементы по локатору")
    def find_elements(self, locator, time=20):
        return WebDriverWait(self.driver, time).until(EC.presence_of_all_elements_located(locator), message=f"Can't found element {locator}")

    @allure.step("Переход на URL")
    def navigate_page(self, url):
        self.driver.get(url)

    @allure.step('Подтверждение аллерта')
    def confirm_allert(self):
        obj = self.driver.switch_to.alert
        obj.accept()

    @allure.step('Получить тескст элемента')
    def get_element_text(self, locator):
        element = self.find_element(locator)
        text = element.get_attribute("innerText")
        return text

    @allure.step('Click element with 3 times')
    def click_element_iterable(self, locator):
        result = False
        waiter = 0
        while(waiter < 3) :
            try:
                element = self.find_element(locator)
                element.click()
                result = True
            except exceptions.StaleElementReferenceException as e:
                print(e)
            except exceptions.ElementNotInteractableException as e:
                print(e)
            waiter += 1
        return result

    @allure.step('Клик по элементу')
    def click_element(self, locator):
        element = self.find_element(locator)
        element.click()
        return element

    @allure.step('Запись текста в элемент')
    def send_keys(self, locator, text):
        element = self.find_element(locator)
        element.send_keys(text)

    @allure.step('Enter в элемент')
    def send_key_values(self, locator, key):
        element = self.find_element(locator)
        element.send_keys(Keys.ENTER)
        return element

    @allure.step('Assert text in element')
    def assert_text(self, locator, text):
        element = self.find_element(locator)
        assert element.text == text, f'Не совпадает текст. Ожидаем - "{text}", /n Получили - "{element.text}"'

    @allure.step('Assert css property')
    def check_element_css_property(self, locator, property, value):
        element = self.find_element(locator)
        assert element.value_of_css_property(property) == value, f"Values are not the same " \
                f"actual-{element.value_of_css_property(property)}, expected-{value}"


    @allure.step("Сабмит елемента")
    def submit(self, locator):
        element = self.find_element(locator)
        element.submit()
